# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["AlbumRestrictionObject"]


class AlbumRestrictionObject(BaseModel):
    published: Optional[bool] = None
    """
    The playlist's public/private status (if it should be added to the user's
    profile or not): `true` the playlist will be public, `false` the playlist will
    be private, `null` the playlist status is not relevant. For more about
    public/private status, see
    [Working with Playlists](/documentation/web-api/concepts/playlists)
    """

    reason: Optional[Literal["market", "product", "explicit"]] = None
    """The reason for the restriction.

    Albums may be restricted if the content is not available in a given market, to
    the user's subscription type, or when the user's account is set to not play
    explicit content. Additional reasons may be added in the future.
    """
